@@ -36,9 +36,7 @@ class SchemaWriter:
         )
 
         parser.add_argument(
-            "--attach-version",
-            action="store_true",
-            help="Add extra directory with schema version number"
+            "--attach-version", action="store_true", help="Add extra directory with schema version number"
         )
         parser.set_defaults(attach_version=False)
 
@@ -74,7 +72,7 @@ class SchemaWriter:
                 sub_directory = Path(output_path) / model_directory_name / schema_version
                 if not os.path.exists(sub_directory):
                     os.makedirs(sub_directory)
-                output_file = sub_directory /schema_filename
+                output_file = sub_directory / schema_filename
             else:
                 output_file = Path(output_path) / schema_filename
 
